@@ -28,6 +28,8 @@ except ImportError:
 
 DEFAULT_ENDPOINT = 'https://notify.bugsnag.com'
 DEFAULT_SESSIONS_ENDPOINT = 'https://sessions.bugsnag.com'
+HUB_ENDPOINT = 'https://notify.insighthub.smartbear.com'
+HUB_SESSIONS_ENDPOINT = 'https://sessions.insighthub.smartbear.com'
 
 __all__ = ('default_headers', 'Delivery')
 
@@ -82,8 +84,10 @@ class Delivery:
         """
         Sends sessions to Bugsnag
         """
-        if (config.endpoint != DEFAULT_ENDPOINT and config.session_endpoint ==
-                DEFAULT_SESSIONS_ENDPOINT):
+        if ((config.endpoint != DEFAULT_ENDPOINT and
+             config.session_endpoint == DEFAULT_SESSIONS_ENDPOINT) or
+            (config.endpoint != HUB_ENDPOINT and
+             config.session_endpoint == HUB_SESSIONS_ENDPOINT)):
             if not self.sent_session_warning:
                 warnings.warn('The session endpoint has not been configured. '
                               'No sessions will be sent to Bugsnag.')
@@ -93,7 +97,6 @@ class Delivery:
                 options = {}
 
             options['endpoint'] = config.session_endpoint
-            options['success'] = 202
 
             self.deliver(config, payload, options)
 
@@ -151,10 +154,14 @@ class UrllibDelivery(Delivery):
             status = resp.getcode()
 
             if 'success' in options:
-                success = options['success']
+                # if an expected status code has been given then it must match
+                # exactly with the actual status code
+                success = status == options['success']
             else:
-                success = 200
-            if status != success:
+                # warn if we don't get a 2xx status code by default
+                success = status >= 200 and status < 300
+
+            if not success:
                 config.logger.warning(
                     'Delivery to %s failed, status %d' % (uri, status)
                 )
@@ -184,12 +191,16 @@ class RequestsDelivery(Delivery):
 
             response = requests.post(uri, **req_options)
             status = response.status_code
-            if 'success' in options:
-                success = options['success']
-            else:
-                success = requests.codes.ok
 
-            if status != success:
+            if 'success' in options:
+                # if an expected status code has been given then it must match
+                # exactly with the actual status code
+                success = status == options['success']
+            else:
+                # warn if we don't get a 2xx status code by default
+                success = status >= 200 and status < 300
+
+            if not success:
                 config.logger.warning(
                     'Delivery to %s failed, status %d' % (uri, status)
                 )
