@@ -15,7 +15,8 @@ def use_client_logger(func):
     def wrapped(obj):
         client = Client(
             api_key='abcdef',
-            endpoint=obj.server.url,
+            endpoint=obj.server.events_url,
+            session_endpoint=obj.server.sessions_url,
             asynchronous=False
         )
 
@@ -44,10 +45,14 @@ def scoped_logger():
 class HandlersTest(IntegrationTest):
     def setUp(self):
         super(HandlersTest, self).setUp()
-        bugsnag.configure(endpoint=self.server.url,
-                          notify_release_stages=['dev'],
-                          release_stage='dev',
-                          asynchronous=False)
+        bugsnag.configure(
+            endpoint=self.server.events_url,
+            session_endpoint=self.server.sessions_url,
+            notify_release_stages=['dev'],
+            release_stage='dev',
+            asynchronous=False,
+        )
+
         bugsnag.logger.setLevel(logging.INFO)
 
     def tearDown(self):
@@ -64,7 +69,7 @@ class HandlersTest(IntegrationTest):
 
         self.assertSentReportCount(1)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('The system is down', exception['message'])
@@ -79,7 +84,7 @@ class HandlersTest(IntegrationTest):
 
         self.assertSentReportCount(1)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogCRITICAL', exception['errorClass'])
@@ -99,7 +104,7 @@ class HandlersTest(IntegrationTest):
 
         self.assertSentReportCount(1)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogERROR', exception['errorClass'])
@@ -118,7 +123,7 @@ class HandlersTest(IntegrationTest):
         logger.removeHandler(handler)
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogWARNING', exception['errorClass'])
@@ -138,7 +143,7 @@ class HandlersTest(IntegrationTest):
         logger.removeHandler(handler)
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogINFO', exception['errorClass'])
@@ -165,7 +170,7 @@ class HandlersTest(IntegrationTest):
         logger.removeHandler(handler)
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogMessage', exception['errorClass'])
@@ -179,7 +184,7 @@ class HandlersTest(IntegrationTest):
         logger.removeHandler(handler)
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogLevel 341', exception['errorClass'])
@@ -194,7 +199,7 @@ class HandlersTest(IntegrationTest):
         logger.removeHandler(handler)
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual('LogOMG', exception['errorClass'])
@@ -213,7 +218,7 @@ class HandlersTest(IntegrationTest):
         logger.removeHandler(handler)
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
         self.assertEqual(exception['errorClass'], 'tests.utils.ScaryException')
@@ -228,7 +233,7 @@ class HandlersTest(IntegrationTest):
         })
         logger.removeHandler(handler)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         self.assertEqual(event['metaData']['fruit'], {
             'grapes': 8, 'pears': 2
@@ -237,7 +242,8 @@ class HandlersTest(IntegrationTest):
     def test_client_metadata_fields(self):
         client = Client(
             api_key='abcdef',
-            endpoint=self.server.url,
+            endpoint=self.server.events_url,
+            session_endpoint=self.server.sessions_url,
             asynchronous=False
         )
 
@@ -252,7 +258,7 @@ class HandlersTest(IntegrationTest):
         })
         logger.removeHandler(handler)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         self.assertEqual(event['metaData']['fruit'], {
             'grapes': 8, 'pears': 2
@@ -263,7 +269,7 @@ class HandlersTest(IntegrationTest):
         logger.critical('The system is down')
         self.assertSentReportCount(1)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -275,7 +281,7 @@ class HandlersTest(IntegrationTest):
 
         self.assertSentReportCount(1)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -292,7 +298,7 @@ class HandlersTest(IntegrationTest):
 
         self.assertSentReportCount(1)
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -308,7 +314,7 @@ class HandlersTest(IntegrationTest):
         logger.warning('The system is down')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -324,7 +330,7 @@ class HandlersTest(IntegrationTest):
         logger.info('The system is down')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -349,7 +355,7 @@ class HandlersTest(IntegrationTest):
         }})
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         self.assertEqual(event['metaData']['food'], {
             'fruit': ['pear', 'grape']
@@ -373,7 +379,7 @@ class HandlersTest(IntegrationTest):
         logger.info('Everything is fine')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         self.assertTrue('tab' not in event['metaData'])
         self.assertEqual(event['metaData']['tab2'], {
@@ -395,7 +401,7 @@ class HandlersTest(IntegrationTest):
         logger.info('Everything is fine')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         self.assertTrue('tab' not in event['metaData'])
         self.assertTrue('tab2' not in event['metaData'])
@@ -415,7 +421,7 @@ class HandlersTest(IntegrationTest):
         logger.info('Everything is fine')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         self.assertEqual(event['metaData']['tab'], {
             'key': 'value', 'key2': 'other value'
@@ -431,7 +437,7 @@ class HandlersTest(IntegrationTest):
         logger.info('Everything is fine')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -448,7 +454,7 @@ class HandlersTest(IntegrationTest):
         logger.info('Everything is fine')
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -462,7 +468,7 @@ class HandlersTest(IntegrationTest):
         logger.info("This happened", extra={'groupingHash': '<hash value>'})
 
         self.assertSentReportCount(1)
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -496,7 +502,7 @@ class HandlersTest(IntegrationTest):
         # the notify caused by the 'error' log
         assert len(handler.client.configuration.breadcrumbs) == 2
 
-        json_body = self.server.received[0]['json_body']
+        json_body = self.server.events_received[0]['json_body']
         event = json_body['events'][0]
         exception = event['exceptions'][0]
 
@@ -639,7 +645,7 @@ class HandlersTest(IntegrationTest):
             # from the notify caused by the 'error' log
             assert len(default_client.configuration.breadcrumbs) == 2
 
-            json_body = self.server.received[0]['json_body']
+            json_body = self.server.events_received[0]['json_body']
             event = json_body['events'][0]
             exception = event['exceptions'][0]
 
